Struct osmo_reflect::msg::CapitalizedResponse
source · [−]pub struct CapitalizedResponse {
pub text: String,
}Fields
text: StringTrait Implementations
sourceimpl Clone for CapitalizedResponse
impl Clone for CapitalizedResponse
sourcefn clone(&self) -> CapitalizedResponse
fn clone(&self) -> CapitalizedResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for CapitalizedResponse
impl Debug for CapitalizedResponse
sourceimpl<'de> Deserialize<'de> for CapitalizedResponse
impl<'de> Deserialize<'de> for CapitalizedResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for CapitalizedResponse
impl JsonSchema for CapitalizedResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<CapitalizedResponse> for CapitalizedResponse
impl PartialEq<CapitalizedResponse> for CapitalizedResponse
sourcefn eq(&self, other: &CapitalizedResponse) -> bool
fn eq(&self, other: &CapitalizedResponse) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &CapitalizedResponse) -> bool
fn ne(&self, other: &CapitalizedResponse) -> bool
This method tests for !=.
sourceimpl Serialize for CapitalizedResponse
impl Serialize for CapitalizedResponse
impl StructuralPartialEq for CapitalizedResponse